@@ -28,7 +28,8 @@ class Visualize:
         manifest: t.Union[str, Path, DataFrame],
         mynorm: t.Union[str, Path, DataFrame],
         poi: t.Union[str, Path, DataFrame],
-        skiprows: int = 7,
+        poi_col: str = "POI",
+        skiprows: int = 0,
         **kwargs,
     ) -> None:
 
@@ -51,13 +52,14 @@ class Visualize:
             )
             self.mynorm = pd.read_csv(mynorm, index_col=0, **kwargs)
             self.poi = pd.read_csv(poi, index_col=0, **kwargs)
-
         else:
             raise InternalException(
-                "Both mynorm and manifest must be not empty and must be the same\
-                                     type: str or DataFrame."
+                "Both mynorm and manifest must be not empty and must be the same type: str or DataFrame."
             )
 
+        self.poi = self.poi[poi_col].to_frame()
+        self.poi.columns = ["POI"]
+
         self.poi = corect_col_names(self.poi)
         self.probes = find_overlap(self.mynorm.index, self.manifest.index)
         check_objects_number(self.probes)
@@ -174,7 +176,7 @@ class Visualize:
             width=width,
             height=height,
             y_range=y_range,
-            category_order=category_order
+            category_order=category_order,
         )
 
         self.__print(fig, static)
@@ -188,6 +190,7 @@ class Visualize:
         start: t.Union[int, None] = None,
         end: t.Union[int, None] = None,
         cpgs: t.Collection = [],
+        mode: str = "box",
         category_order: t.Union[t.List[str], None] = None,
         show_all_points: str = "outliers",
         title: str = "",
@@ -213,26 +216,62 @@ class Visualize:
 
         else:
             raise InternalException(
-                "User must provide chr AND start and END arguments or collection of cpgs to visualize."
+                "User must provide chr AND start and END arguments or any type of collection of cpgs to visualize."
             )
 
-        available_probes = self.manifest[available_probes, "MAPINFO"].sort_values(ascending=True).index
+        available_probes = (
+            self.manifest.loc[available_probes, "MAPINFO"]
+            .sort_values(ascending=True)
+            .index
+        )
         data = self.mynorm.loc[available_probes, :].T
         data = pd.concat((data, self.poi["POI"]), axis=1)
-        data = pd.melt(data, "POI")
 
-        fig = px.box(
-            data,
-            x="variable",
-            y="value",
-            color="POI",
-            width=width,
-            height=height,
-            points=show_all_points,
-        )
+        if category_order:
+            order = category_order
+
+        else:
+            order = self.poi["POI"].unique()
+
+        fig = go.Figure()
+
+        if mode == "box":
+
+            for cpg in available_probes:
+                for group in order:
+                    values = data[data["POI"] == group][cpg]
+                    x_loc = [cpg] * len(values)
+                    fig.add_trace(
+                        go.Box(
+                            y=values,
+                            x=x_loc,
+                            boxpoints=show_all_points,
+                            boxmean=True,
+                            name=group,
+                        )
+                    )
+
+            fig.update_layout(boxmode="group")
+
+        else:
+            for group in order:
+                df = data[data["POI"] == group]
+                df = df.drop("POI", axis=1)
+                df = df.mean()
+
+                x_loc = self.manifest.loc[df.index, "MAPINFO"]
+
+                fig.add_trace(
+                    go.Scatter(
+                        y=df.values,
+                        x=x_loc,
+                        name=group,
+                        mode="lines+markers", hover_data=df.index,
+                    )
+                )
+
         fig = self.__upgrade_figure(
             fig,
-            category_order=category_order,
             title=title,
             show_legend=show_legend,
             x_axis_label=x_axis_label,
@@ -242,7 +281,6 @@ class Visualize:
             width=width,
             height=height,
             y_range=y_range,
-
         )
 
         self.__print(fig, static)
@@ -251,12 +289,12 @@ class Visualize:
             self.__export_figure(fig, static=static, export=export)
 
 
-class EnrichemntAnalysis:
+class EnrichmentAnalysis:
     def __init__(
         self,
         manifest: t.Union[str, DataFrame],
         mynorm: t.Union[str, DataFrame],
-        skiprows: int = 7,
+        skiprows: int = 0,
         **kwargs,
     ):
 
@@ -270,7 +308,11 @@ class EnrichemntAnalysis:
             )
             self.mynorm = pd.read_csv(mynorm, index_col=0, **kwargs)
 
-    def enrichemntAnalysis(
+    @classmethod
+    def load(cls, viz_object: Visualize):
+        return cls(viz_object.manifest, viz_object.mynorm)
+
+    def enrichmentAnalysis(
         self, categories_to_analyse: t.Collection, cpgs: t.Collection
     ) -> None:
         check_categories(self.manifest, categories_to_analyse)
